@@ -287,6 +287,7 @@ class Applicator():
         mythvideo = None
         mythgallery = None
         mythmusic = None
+        mythbuntu_apple_trailers = None
         autologin = None
         autologin_user = None
         samba = None
@@ -347,6 +348,8 @@ class Applicator():
                 mythgallery = self.to_reconfigure[item]
             elif item == "mythmusic":
                 mythmusic = self.to_reconfigure[item]
+            elif item == "mythbuntu_apple_trailers":
+                mythmusic = self.to_reconfigure[item]
             #Autologin
             elif item == "autologin":
                 autologin = self.to_reconfigure[item]
@@ -399,7 +402,7 @@ class Applicator():
             elif item == "diskless_pen":
                 diskless_pen = self.to_reconfigure[item]
             elif item == "diskless_sign":
-                diskless_signed = self.to_reconfigure[item]
+                diskless_sign = self.to_reconfigure[item]
             elif item == "diskless_arch":
                 diskless_arch = self.to_reconfigure[item]
             elif item == "diskless_wol":
@@ -410,7 +413,7 @@ class Applicator():
                 diskless_block_device = self.to_reconfigure[item]
             elif item == "mythbuntu-diskless-server":
                 diskless_server_nfs = self.to_reconfigure[item]
-            elif item == "mythbuntu-diskless-server-standalone":
+            elif item == "dhcp3-server":
                 diskless_server_dhcp = self.to_reconfigure[item]
             elif item == "master-backend-address":
                 master_backend_address = self.to_reconfigure[item]
@@ -469,7 +472,7 @@ class Applicator():
             #self.vnc.toggle_xorg(x11vnc)
             self.vnc.toggle_xorg(False)
             if x11vnc:
-                self.vnc.create_password(vnc_password)
+                self.vnc.create_password('"' + vnc_password + '"')
         else:
             self.update_gui(.375)
         if mysql_server is not None:
@@ -1024,6 +1027,20 @@ class Applicator():
                     progbar.set_fraction(step)
                     fraction = step
 
+            status = pp.wait()
+            if os.WIFEXITED(status):
+                exit_code = os.WEXITSTATUS(status)
+                if exit_code != 0:
+                    header = _("Error building image")
+                    e = _("ltsp-build-client failed with exit code ") + str(exit_code) + _(".\nMaybe you need to enable the \"Allow unsigned packages\" checkbox?")
+                    self.show_alert(gtk.MESSAGE_INFO, header, e, None,
+                        parent=self.progress_dialog)
+            elif os.WIFSIGNALED(status):
+                header = _("Error building image")
+                e = _("ltsp-build-client failed with signal ") + str(os.WTERMSIG(status))
+                self.show_alert(gtk.MESSAGE_INFO, header, e, None,
+                    parent=self.progress_dialog)
+            
             progbar.set_fraction(1.0)
             progbar.set_text('LTSP Setup Done...')
 
@@ -1090,7 +1107,7 @@ class Applicator():
                 # self.check_mount_n_umount(block)
                 # return
             
-            syslinux_conf = 'default diskless\ntimeout 3\nprompt 1\nlabel diskless\nkernel vmlinuz\nappend initrd=initrd.img nbdroot=' + server  + ' ' + wol_arg + ' nbdport=' + nbdport + ' ip=dhcp\n'
+            syslinux_conf = 'default diskless\ntimeout 3\nprompt 1\nlabel diskless\nkernel vmlinuz\nappend initrd=initrd.img nbdroot=' + server  + ' ' + wol_arg + ' nbdport=' + nbdport + ' ip=dhcp quiet splash\n'
 
 
             self.check_mount_n_umount(block)
@@ -1106,6 +1123,7 @@ class Applicator():
             try:
                 shutil.copyfile('/usr/share/doc/ltsp-server/examples/dhcpd.conf','/etc/ltsp/dhcpd.conf')
                 subprocess.check_call(['sed', '-i','/etc/ltsp/dhcpd.conf','-e','s/192.168.0/' + network + '/g'])
+                subprocess.Popen(["invoke-rc.d", "dhcp3-server", "restart"])
             except:
                 pass
                 return
