@@ -144,11 +144,14 @@ class ControlCentre():
             self.user_count=0
             in_f=open("/etc/passwd")
             for line in in_f:
-                fields =  string.split(line,":")
-                id=int(fields[2])
-                if id > 999 and id < 10000:
-                    self.autologin_user.append_text(fields[0])
-                    self.user_count+=1
+                try:
+                    fields =  string.split(line,":")
+                    id=int(fields[2])
+                    if id > 999 and id < 10000:
+                        self.autologin_user.append_text(fields[0])
+                        self.user_count+=1
+                except IndexError:
+                    continue 
             #double check to see if the user 'mythtv' is in usage too.
             if os.path.exists("/etc/gdm/gdm-cdd.conf"):
                 in_f=open("/etc/gdm/gdm-cdd.conf")
@@ -419,7 +422,8 @@ class ControlCentre():
                     to_install.append(item)
                     text+="   Add " + item + " to system.\n"
                 if item == "mplayer" or item == "xine-ui" or item == "vlc" or\
-                   item == "mythvideo" or item == "mythgallery" or item == "mythmusic":
+                   item == "mythvideo" or item == "mythgallery" or item == "mythmusic" or\
+                   item == "mythbuntu_apple_trailers":
                     to_reconfigure[item]=active
         # mythweb auth
         # we only want to change anything if mythweb is installed
@@ -541,8 +545,8 @@ class ControlCentre():
                     basemsg = "I couldn\'t talk to your MySQL server. Is it running?\nIs the connection information in the 'MythTV Configuration' tab correct?"
                     if item == "mythbuntu-diskless-server":
                         self.display_error("Error while configuring mythbuntu-diskless-server.\nPlease update /etc/exports manually or run 'sudo dpkg-reconfigure mythbuntu-diskless-server'\n" + basemsg)
-                    elif item == "mythbuntu-diskless-server-standalone":
-                        self.display_error("Error while configuring mythbuntu-diskless-server-standalone.\nPlease update /etc/ltsp/dhcpd.conf manually.\n" + basemsg)
+                    elif item == "dhcp3-server":
+                        self.display_error("Error while configuring dhcp3-server.\nPlease create /etc/ltsp/dhcpd.conf manually.\n" + basemsg)
 
                 to_install.append(item)
                 text+="   Add " + item + " to system.\n"
@@ -693,26 +697,27 @@ class ControlCentre():
         #automatic login
         seen_title=False
         if old_autologin != new_autologin or old_autologin_user != new_autologin_user:
+            if not seen_title:
+                text+="Automatic Login & Artwork\n"
+                seen_title=True
             if new_autologin_user is not None and new_autologin_user != "[Disabled]":
-                if not seen_title:
-                    text+="Automatic Login & Artwork\n"
-                    seen_title=True
                 if old_autologin != new_autologin and  new_autologin:
                     text+="   Activate automatic login for " + new_autologin_user + ".\n"
                     to_reconfigure["autologin"]=True
                     to_reconfigure["autologin_user"]=new_autologin_user
                     if not self.query_installed("mythbuntu-desktop"):
                         to_install.append("mythbuntu-desktop")
-                elif old_autologin != new_autologin and old_autologin:
-                    text+="   Disable automatic login.\n"
-                    to_reconfigure["autologin"]=False
-                    to_reconfigure["autologin_user"]=old_autologin_user
-                    if self.query_installed("ubuntu-mythtv-frontend"):
-                        to_remove.append("ubuntu-mythtv-frontend")
-                else:
+                elif old_autologin_user != new_autologin_user:
                     text+="   Change automatic login from " + old_autologin_user + " to " + new_autologin_user + ".\n"
                     to_reconfigure["autologin"]=True
                     to_reconfigure["autologin_user"]=new_autologin_user
+
+            elif old_autologin != new_autologin and old_autologin:
+                text+="   Disable automatic login.\n"
+                to_reconfigure["autologin"]=False
+                to_reconfigure["autologin_user"]=old_autologin_user
+                if self.query_installed("ubuntu-mythtv-frontend"):
+                    to_remove.append("ubuntu-mythtv-frontend")
         #artwork
         if old_artwork != new_artwork:
             if not seen_title:
@@ -920,12 +925,17 @@ class ControlCentre():
                         self.diskless_button.set_sensitive(True)
                     else:
                         self.diskless_button.set_sensitive(False)
+                # we also want to have a good configuration file in place
+                elif item == "dhcp3-server":
+                    if result and not os.path.isfile('/etc/ltsp/dhcpd.conf'):
+                        result = False
                 if result:
                     list[item].set_active(True)
                     self.config.set("mythbuntu",item,"True")
                 else:
                     list[item].set_active(False)
                     self.config.set("mythbuntu",item,"False")
+
         #Services
         self.enablesamba.remove_text(2)
         self.enablevnc.remove_text(2)
@@ -1204,13 +1214,17 @@ class ControlCentre():
         # FIXME: what happens if the user removes mythtv-backend? Maybe we should remove the cron job from the system then
         if os.path.exists("/etc/cron.daily/optimize_mythdb.pl"):
             self.enable_mysql_repair.set_active(True)
-            self.mysql_tweak_button.set_sensitive(True)
             self.config.set("mythbuntu","enable_mysql_repair","True")
         else:
             self.enable_mysql_repair.set_active(False)
-            self.mysql_tweak_button.set_sensitive(False)
             self.config.set("mythbuntu","enable_mysql_repair","False")
 
+        # button to run optimize_mythdb.pl
+        if os.path.exists("/usr/share/doc/mythtv-backend/contrib/optimize_mythdb.pl") and self.query_installed("mysql-server"):
+            self.mysql_tweak_button.set_sensitive(True)
+        else:
+            self.mysql_tweak_button.set_sensitive(False)
+
         #Sysctl tweaks
         self.config.set("mythbuntu","enable_ivtv_tweak","False")
         self.config.set("mythbuntu","enable_rtc_tweak","False")
@@ -1637,7 +1651,7 @@ class ControlCentre():
             elif widget.get_name() == 'terminal_button':
                 os.system(getUserApp() + '"x-terminal-emulator"')
             elif widget.get_name() == 'mysql_tweak_button':
-                os.system(getUserApp() + '/usr/bin/x-terminal-emulator -e perl /usr/share/doc/mythtv-backend/contrib/optimize_mythdb.pl')
+                os.system(getUserApp() + '"/usr/bin/x-terminal-emulator -e perl /usr/share/doc/mythtv-backend/contrib/optimize_mythdb.pl"')
             self.main_window.show()
 
 
@@ -1780,4 +1794,16 @@ class ControlCentre():
         else:
             self.diskless_wol_entry.set_sensitive(False)
 
+    # dependency handling for dhcp server installation - we need mythbuntu-diskless-server
+    def on_diskless_server_install_toggled(self,widget=None):
+        if self.diskless_server_install.get_active():
+            self.diskless_server_dhcp.set_sensitive(True)
+            # we always want to force reconfiguration if we don't have /etc/ltsp/dhcpd.conf
+            if self.query_installed("dhcp3-server") and os.path.isfile('/etc/ltsp/dhcpd.conf'):
+                self.diskless_server_dhcp.set_activce(True)
+            else: 
+                self.diskless_server_dhcp.set_active(False)
+        else:
+            self.diskless_server_dhcp.set_sensitive(False)
+            self.diskless_server_dhcp.set_active(False)
 
